@@ -4,12 +4,12 @@
     <message>
         <location filename="main.cpp" line="53"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"/>
+        <translation>Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="main.cpp" line="54"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"/>
+        <translation>Egy másik csomagkezelő alkalmazás (vagy a Synaptic, vagy az apt-get) már fut. Kérem zárja be először ezt az alkalmazást!</translation>
     </message>
     <message>
         <location filename="main.cpp" line="67"/>
@@ -209,12 +209,12 @@
     <message>
         <location filename="codecs.cpp" line="268"/>
         <source>Changelog</source>
-        <translation type="unfinished"/>
+        <translation>Változásbejegyzés</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="284"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Bezár</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
