@@ -14,7 +14,7 @@
     <message>
         <location filename="main.cpp" line="67"/>
         <source>You must run this program as root.</source>
-        <translation>Musisz uruchomić ten program jako administrator. </translation>
+        <translation>Musisz uruchomić ten program jako administrator. </translation>
     </message>
 </context>
 <context>
@@ -38,7 +38,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="codecs.ui" line="94"/>
         <source>Cancel any changes then quit</source>
-        <translation>Cofnij wszelkie zmiany i wyjdź</translation>
+        <translation>Anuluj wszelkie zmiany, a następnie zakończ</translation>
     </message>
     <message>
         <location filename="codecs.ui" line="97"/>
@@ -54,7 +54,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="codecs.ui" line="118"/>
         <source>Apply any changes then quit</source>
-        <translation>Zastosuj zmiany i wyjdź</translation>
+        <translation>Zastosuj wszelkie zmiany, a następnie zakończ</translation>
     </message>
     <message>
         <location filename="codecs.ui" line="121"/>
@@ -101,7 +101,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
         <location filename="codecs.cpp" line="156"/>
         <location filename="codecs.cpp" line="163"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation>&lt;b&gt;Uruchamianie komendy...&lt;/b&gt;&lt;p&gt;</translation>
+        <translation>&lt;b&gt;Uruchamianie polecenia...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="113"/>
@@ -122,7 +122,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
         <location filename="codecs.cpp" line="144"/>
         <location filename="codecs.cpp" line="160"/>
         <source>Cannot connect to the download site</source>
-        <translation>Nie można połączyć się ze stroną pobierania</translation>
+        <translation>Nie można połączyć się ze stroną pobierania</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="120"/>
@@ -130,7 +130,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
         <location filename="codecs.cpp" line="150"/>
         <location filename="codecs.cpp" line="166"/>
         <source>Error downloading %1</source>
-        <translation>Nie można pobrać %1</translation>
+        <translation>Błąd podczas pobierania %1</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="171"/>
@@ -140,7 +140,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="codecs.cpp" line="190"/>
         <source>Installing downloaded files</source>
-        <translation>Instalacja i pobieranie plików</translation>
+        <translation>Instalowanie pobranych plików</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="195"/>
@@ -155,7 +155,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="codecs.cpp" line="215"/>
         <source>Error installing %1</source>
-        <translation>Błąd instalacji %1</translation>
+        <translation>Błąd podczas instalowania %1</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="239"/>
@@ -165,17 +165,17 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="codecs.cpp" line="242"/>
         <source>Finished</source>
-        <translation>Zakończony</translation>
+        <translation>Zakończone</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="243"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation>Pliki kodeków zostały pobrane i zainstalowane.</translation>
+        <translation>Pliki kodeków zostały pomyślnie pobrane i zainstalowane.</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="247"/>
         <source>Process finished. Errors have occurred during the installation.</source>
-        <translation>Proces zakończony z błędami.</translation>
+        <translation>Proces zakończony. Wystąpiły błędy podczas instalacji.</translation>
     </message>
     <message>
         <location filename="codecs.cpp" line="262"/>
